@@ -38,6 +38,7 @@ tar_combine_raw <- function(
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
   format = targets::tar_option_get("format"),
+  repository = targets::tar_option_get("repository"),
   iteration = targets::tar_option_get("iteration"),
   error = targets::tar_option_get("error"),
   memory = targets::tar_option_get("memory"),
@@ -58,6 +59,7 @@ tar_combine_raw <- function(
     packages = packages,
     library = library,
     format = format,
+    repository = repository,
     iteration = iteration,
     error = error,
     memory = memory,
@@ -80,6 +82,7 @@ tar_combine_impl <- function(
   packages,
   library,
   format,
+  repository,
   iteration,
   error,
   memory,
@@ -110,6 +113,7 @@ tar_combine_impl <- function(
     packages = packages,
     library = library,
     format = format,
+    repository = repository,
     iteration = iteration,
     error = error,
     memory = memory,
